@@ -6,6 +6,8 @@
 #
 #  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
 import asyncio
+import os
+import pathlib
 import shlex
 
 from dataclasses import dataclass, field
@@ -35,8 +37,10 @@ async def execute_code_block(code: str, language: str, path: Path, timeout: floa
     else:
         raise ValueError('Unknown language')
 
+    env = os.environ.copy() | {"ORIGIN_DIR": pathlib.Path().resolve()}
+
     process: asyncio.subprocess.Process = await asyncio.create_subprocess_exec(
-        *process_args, cwd=str(path),
+        *process_args, cwd=str(path), env=env,
         stdout=asyncio.subprocess.PIPE, stdin=asyncio.subprocess.PIPE, stderr=asyncio.subprocess.PIPE)
 
     result = RunResult()
